% HEADER
% This file's author is Charles Swanson
% This file's purpose is to analyze the radial scans of the super-hot
% condition measured on 20170824 and 20180129. It was created on 20180130.
% It was tested in MATLAB R2018a

clear
close all
tic

%cd ../../../20180124/xray/analysis/
analyze_radial1;
abel_r_old=abel_r;
abel_f_old=abel_f;
radii_old=radii;
n_old=n;
En_old=En;
%cd ../../../20180129/xray/analysis/
analyze_radial1;
close all

figure('Position',[100 100 [800 600]/2*1.6]);
subplot(1,2,1)
%set(gca,'FontSize',16,'LineWidth',2)
%plot(abel_r_old,abel_f_old(:,:,1),'*--',abel_r,abel_f(:,:,1),'*--','linewidth',2);
hold on;
errorbar(abel_r_old,abel_f_old(:,:,1),0.2*abel_f_old(:,:,1),0.2*abel_f_old(:,:,1),0.6+0*abel_r_old,0.6+0*abel_r_old,'--','linewidth',1);
errorbar(abel_r,abel_f(:,:,1),0.2*abel_f(:,:,1),0.2*abel_f(:,:,1),0.6+0*abel_r,0.6+0*abel_r,'--','linewidth',1);% 0.2 because 10% is approx the error for these inverted EEDFs at the low end and the Abel xform requires a subtraction.
xlabel('Radius (cm)');ylabel('Density above threshold (/cc)');legend('322 A','135 A')
axis([0 max(abel_r)+0.6 0 1.2*max(abel_f(:,:,1))]);
subplot(1,2,2)
%set(gca,'FontSize',16,'LineWidth',2)
%plot(abel_r_old,abel_f_old(:,:,2)./abel_f_old(:,:,1),'*--',abel_r,abel_f(:,:,2)./abel_f(:,:,1),'*--','linewidth',2);
hold on;
errorbar(abel_r_old,abel_f_old(:,:,2)./abel_f_old(:,:,1),0.2*abel_f_old(:,:,2)./abel_f_old(:,:,1),0.2*abel_f_old(:,:,2)./abel_f_old(:,:,1),0.6+0*abel_r_old,0.6+0*abel_r_old,'--','linewidth',1);
errorbar(abel_r,abel_f(:,:,2)./abel_f(:,:,1),0.2*abel_f(:,:,2)./abel_f(:,:,1),0.2*abel_f(:,:,2)./abel_f(:,:,1),0.6+0*abel_r,0.6+0*abel_r,'--','linewidth',1);
xlabel('Radius (cm)');ylabel('Average kinetic energy above threshold (eV)');legend('322 A','135 A')
axis([0 max(abel_r)+0.6 0 1.2*max(abel_f_old(:,:,2)./abel_f_old(:,:,1))]);
saveas(gcf,'radial_abel_eedf_fermi.pdf');

figure('Position',[100 100 [800 600]/2*1.3]);
hold on;
errorbar(abel_r_old,abel_f_old(:,:,2)./abel_f_old(:,:,1),0.2*abel_f_old(:,:,2)./abel_f_old(:,:,1),0.2*abel_f_old(:,:,2)./abel_f_old(:,:,1),0.6+0*abel_r_old,0.6+0*abel_r_old,'--','linewidth',1);
errorbar(abel_r,abel_f(:,:,2)./abel_f(:,:,1),0.2*abel_f(:,:,2)./abel_f(:,:,1),0.2*abel_f(:,:,2)./abel_f(:,:,1),0.6+0*abel_r,0.6+0*abel_r,'--','linewidth',1);
xlabel('Radius (cm)');ylabel('Average kinetic energy above threshold (eV)');legend('238 G','100 G')
axis([0 max(abel_r)+0.6 0 1.2*max(abel_f_old(:,:,2)./abel_f_old(:,:,1))]);
saveas(gcf,'T_e-vs-r-both.pdf');

figure('Position',[100 100 [800 600]/2*1.3]);
hold on;
errorbar(abel_r_old,1e-3*abel_f_old(:,:,2)./abel_f_old(:,:,1),1e-3*0.2*abel_f_old(:,:,2)./abel_f_old(:,:,1),1e-3*0.2*abel_f_old(:,:,2)./abel_f_old(:,:,1),0.6+0*abel_r_old,0.6+0*abel_r_old,'--','linewidth',1);
xlabel('Radius (cm)');ylabel('Avg. kinetic energy above 600 eV (keV)');
axis([0 max(abel_r_old)+0.6 0 1.2*1e-3*max(abel_f_old(:,:,2)./abel_f_old(:,:,1))]);
set(gca,'ytick',0:5);
set(gca,'box','on');
set(gca,'linewidth',1.5);
saveas(gcf,'T_e-vs-r.pdf');

outputString = 'T_e-vs-r';
column1 = abel_r_old;
column2 = 1e-3*abel_f_old(:,:,2)./abel_f_old(:,:,1);
column3 = 1e-3*0.2*abel_f_old(:,:,2)./abel_f_old(:,:,1);
column4 = 0.6+0*abel_r_old;

fid=fopen(sprintf('%s.csv',outputString),'w');
fprintf(fid,sprintf('Radius (cm),KE above 600 eV (keV), KE uncertainty (keV), R uncertainty (cm)\n'));
fclose(fid);

dlmwrite(sprintf('%s.csv',outputString),[column1' column2' column3' column4'],'-append');

toc